@@ -452,10 +452,6 @@ class RedisRoot:
                             allowed_redis_params[django_field_param_name] = value
                     return allowed_redis_params
 
-                exclude_fields = [
-                    'ManyToOneRel',
-                ]
-
                 field_mapping = {
                     django_models.BooleanField: RedisBool,
                     django_models.DecimalField: RedisDecimal,
@@ -480,7 +476,7 @@ class RedisRoot:
                 }
 
 
-                if django_field.__class__.__name__ in exclude_fields:
+                if django_field.__class__.__name__.endswith('Rel'):
                     redis_field = None
                 elif django_field.__class__ in field_mapping.keys():
                     redis_field = field_mapping[django_field.__class__]
